=======================================
`signal_processing` - Signal processing
=======================================

.. testsetup::

   import numpy as np
   from quantities import mV, s, Hz
   import neo
   from elephant.signal_processing import zscore

.. automodule:: elephant.signal_processing
   :members:
